Render Engine FontAwesome

# fontawesome

Adds the fontawesome iconset to render engine themes.

Converts `<i class="fas fa-home"></i>` to .

## How to use this theme

1. Install the theme

       pip install render_engine_fontawesome

2. Import the theme into your project

       from render_engine import Site
       from render_engine_fontawesome import fontawesome

       app = Site()
       app.register_theme(fontawesome)